@@ -58,7 +58,6 @@
 		</description>
 		<see-also>
 			<ref type="application">GosubIf</ref>
-			<ref type="application">Macro</ref>
 			<ref type="application">Goto</ref>
 			<ref type="application">Return</ref>
 			<ref type="application">StackPop</ref>
@@ -93,7 +92,6 @@
 		<see-also>
 			<ref type="application">Gosub</ref>
 			<ref type="application">Return</ref>
-			<ref type="application">MacroIf</ref>
 			<ref type="function">IF</ref>
 			<ref type="application">GotoIf</ref>
 			<ref type="application">Goto</ref>
@@ -202,7 +200,7 @@
 			returning to the dialplan with execution of a Return().</para>
 		</description>
 		<see-also>
-			<ref type="application">GoSub</ref>
+			<ref type="application">Gosub</ref>
 		</see-also>
 	</agi>
 	<managerEvent language="en_US" name="VarSet">
@@ -220,7 +218,7 @@
 				</parameter>
 			</syntax>
 			<see-also>
-				<ref type="application">GoSub</ref>
+				<ref type="application">Gosub</ref>
 				<ref type="agi">gosub</ref>
 				<ref type="function">LOCAL</ref>
 				<ref type="function">LOCAL_PEEK</ref>
